@@ -54,7 +54,7 @@ void Alignment::resetProfile1()
     if (userParameters->getStructPenalties1() != NONE) 
     {
         sl = 0;
-        for (j = 0; j < gapPenaltyMask1.size(); ++j) 
+        for (j = 0; j < (int)gapPenaltyMask1.size(); ++j) 
         {
             if (gapPenaltyMask1[j] == _gapPos1 && (_resetAlignNew ||
                            _resetAlignAll)) 
@@ -73,7 +73,7 @@ void Alignment::resetProfile1()
     if (userParameters->getStructPenalties1() == SECST) 
     {
         sl = 0;
-        for (j = 0; j < secStructMask1.size(); ++j) 
+        for (j = 0; j < (int)secStructMask1.size(); ++j) 
         {
             if (secStructMask1[j] == _gapPos1 && (_resetAlignNew ||
                           _resetAlignAll)) 
@@ -131,7 +131,7 @@ void Alignment::resetProfile2()
     if (userParameters->getStructPenalties2() != NONE) 
     {
         sl = 0;
-        for (j = 0; j < gapPenaltyMask2.size(); ++j) 
+        for (j = 0; j < (int)gapPenaltyMask2.size(); ++j) 
         {
             if (gapPenaltyMask2[j] == _gapPos1 && (_resetAlignNew || _resetAlignAll)) 
             {
@@ -149,7 +149,7 @@ void Alignment::resetProfile2()
     if (userParameters->getStructPenalties2() == SECST) 
     {
         sl = 0;
-        for (j = 0; j < secStructMask2.size(); ++j) 
+        for (j = 0; j < (int)secStructMask2.size(); ++j) 
         {
             if (secStructMask2[j] == _gapPos1 && (_resetAlignNew ||
                          _resetAlignAll)) 
@@ -209,7 +209,7 @@ bool Alignment::addOutputIndex(vector<int>* outputIndexToAdd)
     // First need to clear the old outputIndex
     outputIndex.clear();
     // Check if the size is correct
-    if(outputIndexToAdd->size() == numSeqs)
+    if((int)outputIndexToAdd->size() == numSeqs)
     {
         // Add the output index
         outputIndex = *outputIndexToAdd;
@@ -230,7 +230,7 @@ bool Alignment::addOutputIndex(vector<int>* outputIndexToAdd)
 bool Alignment::appendOutputIndex(vector<int>* outputIndexToAppend)
 {
     // Check if the size is correct
-    if((outputIndexToAppend->size() + outputIndex.size()) == numSeqs)
+    if((int)(outputIndexToAppend->size() + outputIndex.size()) == numSeqs)
     {
         // Append the outputIndex
         vector<int>::iterator outIndexIter = outputIndexToAppend->begin();
@@ -239,14 +239,14 @@ bool Alignment::appendOutputIndex(vector<int>* outputIndexToAppend)
             outputIndex.push_back(*outIndexIter);
             outIndexIter++;
         }
-        if(outputIndex.size() == numSeqs)
+        if((int)outputIndex.size() == numSeqs)
         {
             return true;
         }
         else
         {
             clearAlignment();
-            cout << "There is a problem with adding the sequences\n";
+            cerr << "There is a problem with adding the sequences\n";
             return false;
         }
     }
@@ -329,7 +329,6 @@ void Alignment::pasteSequencesIntoPosition(vector<Sequence>* seqVector, int pos,
     }
     
     int prof1NumSeqs = profile1NumSeqs;
-    int initialProf1NumSeqs = prof1NumSeqs;        
 
     for(int i = numSeqsToInsert - 1; i >= 0; i--)
     {
@@ -354,7 +353,7 @@ void Alignment::pasteSequencesIntoPosition(vector<Sequence>* seqVector, int pos,
     setDefaultOutputIndex();    
 }
 
-void Alignment::printAllNames()
+void Alignment::debugPrintAllNames()
 {
     vector<string>::iterator nameIter = names.begin();
     while(nameIter != names.end())
@@ -391,7 +390,7 @@ bool Alignment::NameIterator::end() {
 }
 
 // 26-03-03,nige: test before appending seqVector
-bool Alignment::testUniqueNames(vector<Sequence>* seqVector)
+bool Alignment::testUniqueNames(vector<Sequence>* seqVector, string *offendingSeq)
 {
     vector<string>::iterator   oldName;
     vector<Sequence>::iterator newName;
@@ -401,8 +400,10 @@ bool Alignment::testUniqueNames(vector<Sequence>* seqVector)
     for (newName = seqVector->begin(); unique && newName != seqVector->end(); newName++) {
         //iterate over old stored names
         for (oldName = names.begin() + 1; unique && oldName != names.end(); oldName++) {
-            if (*oldName == newName->getName())
+            if (*oldName == newName->getName()) {
+                offendingSeq->assign(*oldName);
                 unique = false;
+            }
         }
     }
     return unique;
@@ -426,10 +427,10 @@ void Alignment::addSequencesToVector(vector<Sequence>* seqVector)
         sequenceIds.push_back((*itSeq).getIdentifier());
     }
     
-    if(!((seqArray.size() == numSeqs + 1) && (names.size() == numSeqs + 1)
-          && (titles.size() == numSeqs + 1) && (sequenceIds.size() == numSeqs + 1)))
+    if(!(((int)seqArray.size() == numSeqs + 1) && ((int)names.size() == numSeqs + 1)
+          && ((int)titles.size() == numSeqs + 1) && ((int)sequenceIds.size() == numSeqs + 1)))
     {
-        cout << "There has been an error adding the sequences to Alignment.\n"
+        cerr << "There has been an error adding the sequences to Alignment.\n"
              << "Must terminate the program. EaddSequencesrror occured in addSequences.\n";
         exit(1);
     }
@@ -457,7 +458,7 @@ void Alignment::clearAlignment()
 
 void Alignment::clearSeqArray()
 {
-    for(int i = 0; i < seqArray.size(); i++)
+    for(int i = 0; i < (int)seqArray.size(); i++)
     {
         seqArray[i].clear();
     }
@@ -724,12 +725,12 @@ float Alignment::countid(int s1, int s2)
     return (score);
 }
 
-void Alignment::printSequences()
+void Alignment::debugPrintSequences()
 {
     cout << std::endl;
-    for(int i = 0; i < seqArray.size(); i++)
+    for(int i = 0; i < (int)seqArray.size(); i++)
     {
-        for(int j = 0; j < seqArray[i].size(); j++)
+        for(int j = 0; j < (int)seqArray[i].size(); j++)
         {
             if(seqArray[i][j] > 9)
                 cout << " " << seqArray[i][j];
@@ -755,7 +756,7 @@ void Alignment::calculateMaxLengths()
         while(seqArrayIter != seqArray.end())
         {
             // NOTE I needed to change this to >= for a bug I had!!!!!!!
-            if((*seqArrayIter).size() - 1 >= lengthLongestSequence)
+            if((int)(*seqArrayIter).size() - 1 >= lengthLongestSequence)
             {
                 lengthLongestSequence = (*seqArrayIter).size();
             }
@@ -785,7 +786,7 @@ void Alignment::calculateMaxLengths()
         
         while(nameVecIter != names.end())
         {
-            if((*nameVecIter).size() > maxNames)
+            if((int)(*nameVecIter).size() > maxNames)
             {
                 maxNames = (*nameVecIter).size();
             }
@@ -806,7 +807,7 @@ void Alignment::calculateMaxLengths()
  * This function checks to see if all names are different. It returns true if they
  * are all different, and false if there are 2 the same.
  */
-bool Alignment::checkAllNamesDifferent()
+bool Alignment::checkAllNamesDifferent(string *offendingSeq)
 {
     bool different = true;
     // NOTE I added the + 1 here because, if we had a sequence with a name as blank
@@ -815,6 +816,8 @@ bool Alignment::checkAllNamesDifferent()
     vector<string>::iterator namesIter2;
     int counter1 = 1;
     int counter2 = 2;
+
+    
     while(namesIter1 != names.end())
     {
         namesIter2 = namesIter1 + 1;
@@ -826,6 +829,8 @@ bool Alignment::checkAllNamesDifferent()
                 /* 23-03-2007,nige: let someone up the stack deal with this - GUI is too deeply entangled.
                  * utilityObject->error("Multiple sequences found with same name '%s' (first %d chars are significant)\n", namesIter1->c_str(), MAXNAMES);
                  */
+
+                offendingSeq->assign((*namesIter1));
                 clearAlignment();
                 return different; // Not all different!
             }
@@ -894,7 +899,8 @@ void Alignment::printSequencesAddedInfo()
         int startSeq = userParameters->getProfile2Empty() ? 1:
                        profile1NumSeqs + 1;
         string dnaFlag = userParameters->getDNAFlag() ? "bp" : "aa";
-    
+
+
         for(int i = startSeq; i <= numSeqs; i++) 
         {
             cout << "Sequence " << i << ": " 
@@ -909,8 +915,9 @@ void Alignment::debugPrintOutAlignInfo()
 {
     for(int i = 1; i <= numSeqs; i++) 
     {
-        cout << "Sequence " << i << ": " 
-             << std::left << setw(maxNames) << names.at(i) 
+        cout << "seq-no=" << i << ": name=" 
+             << std::left << setw(maxNames) << names.at(i)
+             << " length=" 
              << std::right << setw(6) << getSequenceLength(i) 
              << std::endl;
     }
@@ -993,7 +1000,7 @@ vector<char>* Alignment::getSecStructMask2()
 
 int Alignment::getSecStructMask1Element(int index)
 {
-    if(index > 0 && index < secStructMask1.size())
+    if(index > 0 && index < (int)secStructMask1.size())
     {
         return secStructMask1[index];
     }
@@ -1005,7 +1012,7 @@ int Alignment::getSecStructMask1Element(int index)
 
 int Alignment::getSecStructMask2Element(int index)
 {
-    if(index > 0 && index < secStructMask2.size())
+    if(index > 0 && index < (int)secStructMask2.size())
     {
         return secStructMask2[index];
     }
@@ -1017,7 +1024,7 @@ int Alignment::getSecStructMask2Element(int index)
 
 int Alignment::getGapPenaltyMask1Element(int index)
 {
-    if(index > 0 && index < gapPenaltyMask1.size())
+    if(index > 0 && index < (int)gapPenaltyMask1.size())
     {
         return gapPenaltyMask1[index];
     }
@@ -1029,7 +1036,7 @@ int Alignment::getGapPenaltyMask1Element(int index)
 
 int Alignment::getGapPenaltyMask2Element(int index)
 {
-    if(index > 0 && index < gapPenaltyMask2.size())
+    if(index > 0 && index < (int)gapPenaltyMask2.size())
     {
         return gapPenaltyMask2[index];
     }
@@ -1041,7 +1048,7 @@ int Alignment::getGapPenaltyMask2Element(int index)
 
 string Alignment::getName(int index)
 {
-    if(index > 0 && index < names.size())
+    if(index > 0 && index < (int)names.size())
     {
         return names[index];
     }
@@ -1057,7 +1064,7 @@ string Alignment::getName(int index)
  */
 unsigned long Alignment::getUniqueId(int seq)
 {
-    if(seq > 0 && seq < sequenceIds.size())
+    if(seq > 0 && seq < (int)sequenceIds.size())
     {
         return sequenceIds[seq];
     }
@@ -1069,7 +1076,7 @@ unsigned long Alignment::getUniqueId(int seq)
 
 string Alignment::getTitle(int index)
 {
-    if(index > 0 && index < titles.size())
+    if(index > 0 && index < (int)titles.size())
     {
         return titles[index];
     }
@@ -1081,7 +1088,7 @@ string Alignment::getTitle(int index)
 
 int Alignment::getOutputIndex(int index)
 {
-    if(index >= 0 && index < outputIndex.size())
+    if(index >= 0 && index < (int)outputIndex.size())
     {
         return outputIndex[index];
     }
@@ -1093,7 +1100,7 @@ int Alignment::getOutputIndex(int index)
 
 int Alignment::getSeqWeight(int index) const
 {
-    if(index >= 0 && index < seqWeight.size())
+    if(index >= 0 && index < (int)seqWeight.size())
     {
         return seqWeight[index];
     }
@@ -1116,7 +1123,7 @@ vector<int>* Alignment::QTcalcHistColumnHeights(int firstSeq, int nSeqs,
 {
     int n, i, s, p, r, r1;
     int numColumns = getLengthLongestSequence();
-    int scoreScale = userParameters->getQTScorePlotScale();//5; // From ClautalX.
+    int scoreScale = userParameters->getQTScorePlotScale();//5; // From ClustalX.
     int scoreCutOff = userParameters->getQTResExceptionCutOff();
     bool includeGaps = false;
     //short  *mat_xref, *matptr;
@@ -1124,14 +1131,12 @@ vector<int>* Alignment::QTcalcHistColumnHeights(int firstSeq, int nSeqs,
     float t, q1, q3, ul;
     vector<float> seqdist, sorteddist;
     float diff;
-    int maxRes;
     vector<int> seqvector;
     vector<int> freq;
     vector<vector<int> > profile;
     int matrix[NUMRES][NUMRES];
     int _maxAA = userParameters->getMaxAA();
     int _gapPos1 = userParameters->getGapPos1();
-    int _gapPos2 = userParameters->getGapPos2();
     histogramColumnHeights.resize(numColumns);
     //panel_data data1;
     subMatrix->getQTMatrixForHistogram(matrix);
@@ -1439,7 +1444,7 @@ void Alignment::removeGapsFromSelectedSeqs(vector<int>* selected)
             // Then remove the excess bit at the end of the array
             int numExtraElements = lengthOfSelectedSeq - s1;
             
-            if(seqArray[i].size() > numExtraElements)
+            if((int)seqArray[i].size() > numExtraElements)
             {
                 for(int k = 0; k < numExtraElements; k++)
                 {
@@ -1498,7 +1503,7 @@ void Alignment::removeGapOnlyColsFromSelectedSeqs(vector<int>* selected)
             //cout << "                removing a gap column\n\n";
             for(int j = firstSeqSelected; j < sizeSelected && (*selected)[j] == 1; j++)
             {
-                for(k = i + 1; k <= getSeqLength(j) + 1 && seqArray[j].size() > k; k++)
+                for(k = i + 1; k <= getSeqLength(j) + 1 && (int)seqArray[j].size() > k; k++)
                 {
                     seqArray[j][k - 1] = seqArray[j][k];
                 }
@@ -1685,7 +1690,7 @@ bool Alignment::removeAllOutsideRange(int beginPos, int endPos)
     ok = keepPortionOfSeqArray(beginPos, endPos);
     if(!ok)
     {
-        cout << "There was a problem removing a portion of the array\n";
+        cerr << "There was a problem removing a portion of the array\n";
         return false;
     }
     
@@ -1757,7 +1762,7 @@ bool Alignment::keepPortionOfSeqArray(int beginRangeIndex, int endRangeIndex)
     return true; 
 }
 
-void Alignment::printSeqArray(SeqArray* arrayToPrint)
+void Alignment::debugPrintSeqArray(SeqArray* arrayToPrint)
 {
     // I need to use iterators for everything here.
     SeqArray::iterator mainBeginIt = arrayToPrint->begin();
@@ -1773,7 +1778,7 @@ void Alignment::printSeqArray(SeqArray* arrayToPrint)
             end = mainBeginIt->end();
             for(; begin != end; begin++)
             {
-                if(*begin < aaCodes.size())
+                if(*begin < (int)aaCodes.size())
                 {
                     cout << aaCodes[*begin];
                 }
@@ -1787,7 +1792,7 @@ void Alignment::printSeqArray(SeqArray* arrayToPrint)
     }
 }
 
-void Alignment::printProfile1()
+void Alignment::debugPrintProfile1()
 {
     cout << "************** PROFILE1 *********************\n";
     SeqArray::iterator mainBeginIt = seqArray.begin() + 1;
@@ -1804,7 +1809,7 @@ void Alignment::printProfile1()
             end = mainBeginIt->end();
             for(; begin != end; begin++)
             {
-                if(*begin < aaCodes.size())
+                if(*begin < (int)aaCodes.size())
                 {
                     cout << aaCodes[*begin];
                 }
@@ -1818,7 +1823,7 @@ void Alignment::printProfile1()
     }
 }
 
-void Alignment::printProfile2()
+void Alignment::debugPrintProfile2()
 {
     cout << "************** PROFILE2 *********************\n";
     SeqArray::iterator mainBeginIt = seqArray.begin() + 1 + profile1NumSeqs;
@@ -1835,7 +1840,7 @@ void Alignment::printProfile2()
             end = mainBeginIt->end();
             for(; begin != end; begin++)
             {
-                if(*begin < aaCodes.size())
+                if(*begin < (int)aaCodes.size())
                 {
                     cout << aaCodes[*begin];
                 }
@@ -1903,7 +1908,7 @@ bool Alignment::reloadAlignment()
     {
         return true;
     }
-    if(outputIndex.size() != getNumSeqs())
+    if((int)outputIndex.size() != getNumSeqs())
     {
         outputIndex.clear();
         return false;
@@ -1934,7 +1939,7 @@ bool Alignment::reloadAlignment()
     // Now for each seq,
     for(int i = 1; i < size; i++)
     { 
-        if(i < outputOrderSeqArray.size() && i - 1 < outputIndex.size() &&
+        if(i < (int)outputOrderSeqArray.size() && i - 1 < (int)outputIndex.size() &&
            outputIndex[i - 1] < size)
         {
             _outIndex = outputIndex[i - 1];
@@ -1959,11 +1964,13 @@ bool Alignment::reloadAlignment()
     titles = outputOrderTitles;
     sequenceIds.clear();
     sequenceIds = outputOrderSequenceIds; 
+
+    return true;
 }
 
 const vector<int>* Alignment::getSequenceFromUniqueId(unsigned long id)
 {
-    for(int i = 0; i < sequenceIds.size(); i++)
+    for(int i = 0; i < (int)sequenceIds.size(); i++)
     {
         if(sequenceIds[i] == id)
         {
@@ -1981,7 +1988,7 @@ const vector<int>* Alignment::getSequenceFromUniqueId(unsigned long id)
  */
 void Alignment::updateSequence(int index, const vector<int>* seq)
 {
-    if(index >= 1 && index < seqArray.size())
+    if(index >= 1 && index < (int)seqArray.size())
     {
         seqArray[index] = *seq;
     }
