@@ -82,9 +82,10 @@ void AlignmentOutput::createAlignmentOutput(Alignment* alignPtr, int firstSeq, i
     
     if((firstSeq <= 0) || (lastSeq < firstSeq))
     {
-        cout << "ERROR: Cannot produce alignment output. " 
-             << "Incorrect call to createAlignmentOutput."
-             << "firstSeq = " << firstSeq << " lastSeq = " << lastSeq << "\n";
+        utilityObject->error("Cannot produce alignment output."
+                " Incorrect call to createAlignmentOutput."
+                " firstSeq = %d"
+                " lastSeq = %d\n", firstSeq, lastSeq);
         return;
     }
     
@@ -105,7 +106,7 @@ void AlignmentOutput::createAlignmentOutput(Alignment* alignPtr, int firstSeq, i
             // Check if the numbers are ok.
             if ((firstRes > lastRes) || (firstRes == -1) || (lastRes == -1)) 
             {
-                cout << "seqrange numbers are not set properly, using default....\n";
+                cerr << "seqrange numbers are not set properly, using default....\n";
                 firstRes = 1;
                 lastRes = length;
             }
@@ -335,7 +336,9 @@ bool AlignmentOutput::openAlignmentOutput(string path)
     string _fileNameToOutput = path;
     if(_fileNameToOutput == "")
     {
-        _fileNameToOutput = userParameters->getSeqName();
+      /*_fileNameToOutput = userParameters->getSeqName();*/
+      /* BUG 166 , file extension, FS, 2009-01-26 */
+      utilityObject->getPath(userParameters->getSeqName(), &_fileNameToOutput);
     }
     
     if(userParameters->getOutputClustal()) 
@@ -663,21 +666,21 @@ void AlignmentOutput::fastaOut(Alignment* alignPtr, outputRegion partToOutput)
     catch(const bad_alloc& e)
     {
         fastaOutFile->close();
-        cout << "A bad_alloc exception has occured in the fastaOut function.\n"
+        cerr << "A bad_alloc exception has occured in the fastaOut function.\n"
              << e.what() << "\n";
         exit(1);
     }
     catch(VectorOutOfRange e)
     {
         fastaOutFile->close();
-        cout << "An exception has occured in the fastaOut function.\n"
+        cerr << "An exception has occured in the fastaOut function.\n"
              << e.what() << "\n";
         exit(1);    
     }
     catch(...)
     {
         fastaOutFile->close();
-        cout << "An exception has occured in the fastaOut function.\n";
+        cerr << "An exception has occured in the fastaOut function.\n";
         exit(1);    
     }
 
@@ -858,21 +861,21 @@ void AlignmentOutput::gcgOut(Alignment* alignPtr, outputRegion partToOutput)
     catch(const bad_alloc& e)
     {
         gcgOutFile->close();
-        cout << "A bad_alloc exception has occured in the gcgOut function.\n"
+        cerr << "A bad_alloc exception has occured in the gcgOut function.\n"
              << e.what() << "\n";
         exit(1);
     }
     catch(VectorOutOfRange e)
     {
         gcgOutFile->close();
-        cout << "An exception has occured in the gcgOut function.\n"
+        cerr << "An exception has occured in the gcgOut function.\n"
              << e.what() << "\n";
         exit(1);    
     }
     catch(...)
     {
         gcgOutFile->close();
-        cout << "An exception has occured in the gcgOut function.\n";
+        cerr << "An exception has occured in the gcgOut function.\n";
         exit(1);    
     }    
 }
@@ -912,9 +915,9 @@ void AlignmentOutput::phylipOut(Alignment* alignPtr, outputRegion partToOutput)
         if(nameLen > 10) 
         {
             warn = false;
-            for(i = 0; i < _seqNames.size() - 1; i++)  
+            for(i = 0; i < (int)_seqNames.size() - 1; i++)  
             {
-                for(j = i + 1; j < _seqNames.size(); j++) 
+                for(j = i + 1; j < (int)_seqNames.size(); j++) 
                 {
                     if (_seqNames[i].compare(_seqNames[j]) == 0) 
                     {
@@ -1017,21 +1020,21 @@ void AlignmentOutput::phylipOut(Alignment* alignPtr, outputRegion partToOutput)
     catch(const bad_alloc& e)
     {
         phylipOutFile->close();
-        cout << "A bad_alloc exception has occured in the phylipOut function.\n"
+        cerr << "A bad_alloc exception has occured in the phylipOut function.\n"
              << e.what() << "\n";
         exit(1);
     }
     catch(VectorOutOfRange e)
     {
         phylipOutFile->close();
-        cout << "An exception has occured in the phylipOut function.\n"
+        cerr << "An exception has occured in the phylipOut function.\n"
              << e.what() << "\n";
         exit(1);    
     }
     catch(...)
     {
         phylipOutFile->close();
-        cout << "An exception has occured in the phylipOut function.\n";
+        cerr << "An exception has occured in the phylipOut function.\n";
         exit(1);    
     }      
 }
@@ -1141,21 +1144,21 @@ void AlignmentOutput::nexusOut(Alignment* alignPtr, outputRegion partToOutput)
     catch(const bad_alloc& e)
     {
         nexusOutFile->close();
-        cout << "A bad_alloc exception has occured in the nexusOut function.\n"
+        cerr << "A bad_alloc exception has occured in the nexusOut function.\n"
              << e.what() << "\n";
         exit(1);
     }
     catch(VectorOutOfRange e)
     {
         nexusOutFile->close();
-        cout << "An exception has occured in the nexusOut function.\n"
+        cerr << "An exception has occured in the nexusOut function.\n"
              << e.what() << "\n";
         exit(1);    
     }
     catch(...)
     {
         nexusOutFile->close();
-        cout << "An exception has occured in the nexusOut function.\n";
+        cerr << "An exception has occured in the nexusOut function.\n";
         exit(1);    
     }      
 }
@@ -1430,21 +1433,21 @@ void AlignmentOutput::gdeOut(Alignment* alignPtr, outputRegion partToOutput)
     catch(const bad_alloc& e)
     {
         gdeOutFile->close();
-        cout << "A bad_alloc exception has occured in the gdeOut function.\n"
+        cerr << "A bad_alloc exception has occured in the gdeOut function.\n"
              << e.what() << "\n";
         exit(1);
     }
     catch(VectorOutOfRange e)
     {
         gdeOutFile->close();
-        cout << "An exception has occured in the gdeOut function.\n"
+        cerr << "An exception has occured in the gdeOut function.\n"
              << e.what() << "\n";
         exit(1);    
     }
     catch(...)
     {
         gdeOutFile->close();
-        cout << "An exception has occured in the gdeOut function.\n";
+        cerr << "An exception has occured in the gdeOut function.\n";
         exit(1);    
     }     
 }
@@ -1545,21 +1548,21 @@ void AlignmentOutput::nbrfOut(Alignment* alignPtr, outputRegion partToOutput)
     catch(const bad_alloc& e)
     {
         nbrfOutFile->close();
-        cout << "A bad_alloc exception has occured in the nbrfOut function.\n"
+        cerr << "A bad_alloc exception has occured in the nbrfOut function.\n"
              << e.what() << "\n";
         exit(1);
     }
     catch(VectorOutOfRange e)
     {
         nbrfOutFile->close();
-        cout << "An exception has occured in the nbrfOut function.\n"
+        cerr << "An exception has occured in the nbrfOut function.\n"
              << e.what() << "\n";
         exit(1);    
     }
     catch(...)
     {
         nbrfOutFile->close();
-        cout << "An exception has occured in the nbrfOut function.\n";
+        cerr << "An exception has occured in the nbrfOut function.\n";
         exit(1);    
     }    
 }
@@ -1694,7 +1697,7 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
             
             string secStructName1 = alignPtr->getSecStructName1(); // Mark 18-7-07
             
-            if(secStructName1.size() > MAXNAMESTODISPLAY)
+            if((int)secStructName1.size() > MAXNAMESTODISPLAY)
             {
                 //secStructName1 = secStructName1.substr(0, MAXNAMESTODISPLAY);
                 secStructName1 = secStructName1.substr(0, NAMESWIDTH);
@@ -1707,7 +1710,7 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
                     for(i = pos; i <= ptr; ++i) 
                     {
                         // Check if we can access mask position first
-                        if(ss_mask1.size() > i + firstRes - 2)  
+                        if((int)ss_mask1.size() > i + firstRes - 2)  
                         {
                             val = ss_mask1[i + firstRes - 2]; 
                             if (val == userParameters->getGapPos1() || 
@@ -1752,7 +1755,7 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
                     vector<char>* _gapPenaltyMask1 = alignPtr->getGapPenaltyMask1();       
                     for(i = pos; i <= ptr; ++i) 
                     {
-                        if(_gapPenaltyMask1->size() > i + firstRes - 2) 
+                        if((int)_gapPenaltyMask1->size() > i + firstRes - 2) 
                         {
                             val = _gapPenaltyMask1->at(i + firstRes - 2); 
                             if (val == userParameters->getGapPos1() || 
@@ -1781,8 +1784,8 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
             
             
             string secStructName2 = alignPtr->getSecStructName2(); // Mark 18-7-07
-            //if(secStructName2.size() > MAXNAMESTODISPLAY)
-            if(secStructName2.size() > NAMESWIDTH)
+            //if((int)secStructName2.size() > MAXNAMESTODISPLAY)
+            if((int)secStructName2.size() > NAMESWIDTH)
             {
                 //secStructName2 = secStructName2.substr(0, MAXNAMESTODISPLAY);
                 secStructName2 = secStructName2.substr(0, NAMESWIDTH);
@@ -1795,7 +1798,7 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
                 {
                     for(i = pos; i <= ptr; ++i) 
                     {
-                        if(ss_mask2.size() > i + firstRes - 2)
+                        if((int)ss_mask2.size() > i + firstRes - 2)
                         {
                             val = ss_mask2[i + firstRes - 2]; 
                             if (val == userParameters->getGapPos1() || 
@@ -1842,7 +1845,7 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
                     vector<char>* _gapPenaltyMask2 = alignPtr->getGapPenaltyMask2();
                     for(i = pos; i <= ptr; ++i) 
                     {
-                        if(_gapPenaltyMask2->size() > i + firstRes - 2)
+                        if((int)_gapPenaltyMask2->size() > i + firstRes - 2)
                         {
                             val = _gapPenaltyMask2->at(i + firstRes - 2); 
                             if (val == userParameters->getGapPos1() || 
@@ -1912,8 +1915,8 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
                 }
                 
                 string seqName = alignPtr->getName(i);
-                //if(seqName.size() > MAXNAMESTODISPLAY)
-                if(seqName.size() > NAMESWIDTH)
+                //if((int)seqName.size() > MAXNAMESTODISPLAY)
+                if((int)seqName.size() > NAMESWIDTH)
                 {
                     //seqName = seqName.substr(0, MAXNAMESTODISPLAY);
                     seqName = seqName.substr(0, NAMESWIDTH);
@@ -1968,11 +1971,11 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
                 seq1[i] = ' ';
                 ident = 0;
 
-                for(j = 1; j <= strongGroup.size(); j++)
+                for(j = 1; j <= (int)strongGroup.size(); j++)
                 {
                     catident1[j - 1] = 0;
                 }
-                for(j = 1; j <= weakGroup.size(); j++) 
+                for(j = 1; j <= (int)weakGroup.size(); j++) 
                 {
                     catident2[j - 1] = 0;
                 }
@@ -1993,7 +1996,7 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
                                 ++ident;
                             }
                             // Count how many are in the same category.
-                            for(k = 1; k <= strongGroup.size(); k++) 
+                            for(k = 1; k <= (int)strongGroup.size(); k++) 
                             {
                                 for(l = 0; (c = strongGroup[k - 1][l]); l++) 
                                 {
@@ -2008,7 +2011,7 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
                                     }
                                 }
                             }
-                            for(k = 1; k <= weakGroup.size(); k++) 
+                            for(k = 1; k <= (int)weakGroup.size(); k++) 
                             {
                                 for(l = 0; (c = weakGroup[k - 1][l]); l++) 
                                 {//NOTE june29
@@ -2034,7 +2037,7 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
                 }
                 else if (!userParameters->getDNAFlag()) 
                 {
-                    for(k = 1; k <= strongGroup.size(); k++) 
+                    for(k = 1; k <= (int)strongGroup.size(); k++) 
                     {
                         if (catident1[k - 1] == lastSeq - firstSeq + 1) 
                         {
@@ -2044,7 +2047,7 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
                     }
                     if(seq1[i] == ' ')
                     {
-                        for(k = 1; k <= weakGroup.size(); k++) 
+                        for(k = 1; k <= (int)weakGroup.size(); k++) 
                         {
                             if (catident2[k - 1] == lastSeq - firstSeq + 1) 
                             {
@@ -2080,28 +2083,28 @@ void AlignmentOutput::clustalOut(Alignment* alignPtr, outputRegion partToOutput)
     catch(const bad_alloc& e)
     {
         clustalOutFile->close();
-        cout << "A bad_alloc exception has occured in the clustalOut function.\n"
+        cerr << "A bad_alloc exception has occured in the clustalOut function.\n"
              << e.what() << "\n";
         exit(1);
     }
     catch(VectorOutOfRange e)
     {
         clustalOutFile->close();
-        cout << "An exception has occured in the clustalOut function.\n"
+        cerr << "An exception has occured in the clustalOut function.\n"
              << e.what() << "\n";
         exit(1);    
     }
     catch(exception e)
     {
         clustalOutFile->close();
-        cout << "An exception has occured in the clustalOut function.\n"
+        cerr << "An exception has occured in the clustalOut function.\n"
              << e.what() << "\n";
         exit(1);    
     }
     catch(...)
     {
         clustalOutFile->close();
-        cout << "An exception has occured in the clustalOut function.\n";
+        cerr << "An exception has occured in the clustalOut function.\n";
         exit(1);    
     }    
 }
@@ -2321,7 +2324,7 @@ void AlignmentOutput::findRangeValues(Alignment* alignPtr, rangeNum *rnum, int f
         }
         else 
         {
-            cout << "\n no range found .... strange,  iStart = " << iStart;
+            cerr << "\n no range found .... strange,  iStart = " << iStart;
             formula = 1;
         }
         if (pregaps == firstRes - 1) // all gaps -  now the conditions........ 
@@ -2342,7 +2345,7 @@ void AlignmentOutput::findRangeValues(Alignment* alignPtr, rangeNum *rnum, int f
     }
     catch(VectorOutOfRange e)
     {
-        cout << "An exception has occured in the findRangeValues function.\n"
+        cerr << "An exception has occured in the findRangeValues function.\n"
              << e.what() << "\n";
         exit(1);    
     }    
@@ -2360,7 +2363,7 @@ string AlignmentOutput::nameonly(string s)
     {
         int i = 0;
 
-        while (i < s.size()) 
+        while (i < (int)s.size()) 
         {
             if(s.at(i) != '/')
             {
