@@ -47,11 +47,12 @@ FileReader::~FileReader()
 /* check if we've read sequences without any information, i.e. header
  *  but no sequence at all
  */
-bool FileReader::noEmptySequence(vector<Sequence> seqVector)
+bool FileReader::noEmptySequence(vector<Sequence> seqVector, string *offendingSeq)
 {
     vector<Sequence>::iterator si;
     for (si = seqVector.begin(); si != seqVector.end(); si++) {
         if (si->isEmpty()) {
+            offendingSeq->assign(si->getName());
             return false;
         }
     }
@@ -66,11 +67,10 @@ bool FileReader::noEmptySequence(vector<Sequence> seqVector)
  * It is called twice in the interactive menu, both times with append as false. It calls
  * the readseqs function to do the work.
  */
-int FileReader::seqInput(Alignment *alignPtr, bool append)
+    int FileReader::seqInput(Alignment *alignPtr, bool append, string *offendingSeq)
 {
-    int i;
     int code;
-
+    
     if(userParameters->getMenuFlag()) 
     {
         cout << "\n\nSequences should all be in 1 file.\n"; 
@@ -82,11 +82,11 @@ int FileReader::seqInput(Alignment *alignPtr, bool append)
     if (append)
     {
         int numSeqsAlready = alignPtr->getNumSeqs();
-        code = readSeqs(alignPtr, numSeqsAlready + 1);
+        code = readSeqs(alignPtr, numSeqsAlready + 1, offendingSeq);
     }
     else
     {
-        code = readSeqs(alignPtr, 1);  //  1 is the first seq to be read 
+        code = readSeqs(alignPtr, 1, offendingSeq);  //  1 is the first seq to be read 
     }
 
     if(code == OK)
@@ -135,8 +135,11 @@ int FileReader::seqInput(Alignment *alignPtr, bool append)
  * The function readSeqs will create the FileParser that is needed and
  * it will read in all of the sequences. Depending on the filetype, it
  * will also check for secondary structure information.
+ *
+ * If there is a problem with one of the sequences its name will be
+ * assigned to offendingSeq
  */
-int FileReader::readSeqs(Alignment *alignPtr, int firstSeq)
+    int FileReader::readSeqs(Alignment *alignPtr, int firstSeq, string *offendingSeq)
 {
     string line;
     string fileName;
@@ -165,7 +168,7 @@ int FileReader::readSeqs(Alignment *alignPtr, int firstSeq)
     if (line.length() == 0)
     {
         // We have no fileName, so return -1
-        return  -1;
+        return -1;
     }
     
     // If we have file:// in the string, remove it!!
@@ -178,7 +181,7 @@ int FileReader::readSeqs(Alignment *alignPtr, int firstSeq)
     // Now we have the file name, we must open the file.
     fileIn->open(line.c_str());  //nige
     if (fileIn->fail())
-        return  CANNOTOPENFILE; 
+        return CANNOTOPENFILE; 
 
     sequenceFileName = line;
     
@@ -186,7 +189,7 @@ int FileReader::readSeqs(Alignment *alignPtr, int firstSeq)
     if (!fileIn->is_open())
     {
         utilityObject->error("Cannot open input file (%s)\n", line.c_str());
-        return  CANNOTOPENFILE; 
+        return CANNOTOPENFILE; 
     }
         
     userParameters->setSeqName(line);
@@ -212,17 +215,18 @@ int FileReader::readSeqs(Alignment *alignPtr, int firstSeq)
     }
 
 
-    seqRangeVector = fileParser->getSeqRange(1, noSeqs);
+    seqRangeVector = fileParser->getSeqRange(1, noSeqs, offendingSeq);
     if (seqRangeVector.size()==0)
         return fileParser->getParseExitCode();
-    // FIXME AW: noEmptySequence check should be done internally by FileParser instances
-    if (noEmptySequence(seqRangeVector) == false)
+    // FIXME Andreas Wilm (UCD): noEmptySequence check should be done
+    // internally by FileParser instances
+    if (noEmptySequence(seqRangeVector, offendingSeq) == false) {
         return EMPTYSEQUENCE; // Error there are same names.
-
+    }
             
-    for (int i=0; i<seqRangeVector.size(); i++) {
+    for (int i=0; i < (int)seqRangeVector.size(); i++) {
         // Andreas Wilm (UCD): fixed wrong default output order
-        // which important when no alignment (convert!) is done
+        // which is important when no alignment (convert!) is done
         // _outputIndex.push_back(i); // default output order
         _outputIndex.push_back(i+1); // default output order
 
@@ -250,7 +254,7 @@ int FileReader::readSeqs(Alignment *alignPtr, int firstSeq)
         int prfNum = userParameters->getProfileNum();
         alignPtr->addSequences(&seqVector);
         //test names after saving
-        if(alignPtr->checkAllNamesDifferent() == false) {  //nige moved
+        if(alignPtr->checkAllNamesDifferent(offendingSeq) == false) {  //nige moved
             return ALLNAMESNOTDIFFERENT; // Error there are same names.
         }
         
@@ -263,7 +267,7 @@ int FileReader::readSeqs(Alignment *alignPtr, int firstSeq)
     else // profile2
     {
         //test names before appending
-        if (! alignPtr->testUniqueNames(&seqVector)) {  //nige added
+        if (! alignPtr->testUniqueNames(&seqVector, offendingSeq)) {  //nige added
             return ALLNAMESNOTDIFFERENT;
         }
         alignPtr->appendSequences(&seqVector);
@@ -314,6 +318,7 @@ int FileReader::profileInput(Alignment *alignPtr)
 {
     int code;
     //int i, totalNumOfSeqs = 0;
+    string offendingSeq;
     
     if(userParameters->getProfileNum() == 2 && userParameters->getProfile1Empty()) 
     {
@@ -323,7 +328,7 @@ int FileReader::profileInput(Alignment *alignPtr)
 
     if(userParameters->getProfileNum() == 1)     // for the 1st profile 
     {
-        code = readSeqs(alignPtr, 1);
+        code = readSeqs(alignPtr, 1, &offendingSeq);
 
         if (code == OK)
         {   
@@ -350,24 +355,16 @@ int FileReader::profileInput(Alignment *alignPtr)
             userParameters->setProfile2Empty(true);
             cout << "No. of seqs = " << alignPtr->getNumSeqs() << endl;
         }
-        else if(code == NOSEQUENCESINFILE)         // no sequences
-        {
-            /* 02-04-07,nige: this causes a fatal repaint: let
-             *  MainWindow::errorHandler deal with it.
-             */
-            //utilityObject->error("No sequences in file!  Bad format?\n");
-            return code;
-        }
         else
         {
-            return code;
+            return code; // FIXME and offendingSeq?
         }
     }
     else
     {                    
         // first seq to be read = profile1_nseqs + 1 
         int profile1NumOfSeqs = alignPtr->getNumSeqs();
-        code = readSeqs(alignPtr, profile1NumOfSeqs + 1); 
+        code = readSeqs(alignPtr, profile1NumOfSeqs + 1, &offendingSeq); 
         if(code == OK)
         {
             userParameters->setStructPenalties2(NONE);
@@ -389,21 +386,9 @@ int FileReader::profileInput(Alignment *alignPtr)
             userParameters->setProfile2Empty(false);
             userParameters->setEmpty(false); 
         }
-        else if(code == CANNOTOPENFILE)
-        {
-            return CANNOTOPENFILE;
-        }
-        else if(code == NOSEQUENCESINFILE)         // no sequences
-        {
-            /* 02-04-07,nige: this causes a fatal repaint: let
-             *  MainWindow::errorHandler deal with it.
-             */
-            //utilityObject->error("No sequences in file!  Bad format?\n");
-            return code;
-        }
         else
         {
-            return code;
+            return code; // FIXME and offendingSeq?
         }
     }
     // Clear out the masks used in this class. This is important!!!!
@@ -411,11 +396,6 @@ int FileReader::profileInput(Alignment *alignPtr)
     gapPenaltyMask.clear();
     secStructName = "";
     
-    if(code != OK)
-    { 
-        return code;
-    }
-    
     string typeOfAlign = userParameters->getDNAFlag() ? "DNA" : "PROTEIN";
     cout << "Sequences assumed to be "
          << typeOfAlign << endl;
