@@ -14,7 +14,7 @@
 #endif
 #include <stdio.h>
 #include <string>
-#include <stdlib.h>
+#include <cstdlib>
 #include <exception>
 #include <iostream>
 #include <limits>
@@ -285,13 +285,17 @@ void UserParameters::setParamsToDefault()
 /*
  * The function createParameterOutput is used to put all the user parameters in
  * a file. It is used for testing and for saving parameters.
+ *
+ *
+ * FIXME: AW: Some parameters are missing here (e.g. the new ones like
+ * clustering, etc)
+ *
  */
 void UserParameters::createParameterOutput(void)
 {
     string parname, temp;
     string path;
     string message;
-    FILE *parout;
   
     utilityObject->getPath(seqName, &path);
     parname = path + "par";
@@ -310,7 +314,7 @@ void UserParameters::createParameterOutput(void)
     
     if(!outfile)
     {
-        return; // Failed to open!!!!!!!!!
+        return; // Failed to open
     }
     
     outfile << "clustalw \\\n";
