@@ -170,7 +170,7 @@ void Utility::getStr(string instr, string& outstr)
  * @param def 
  * @return 
  */
-double Utility::getReal(char *instr, double minx, double maxx, double def)
+double Utility::getReal(const char *instr, double minx, double maxx, double def)
 {
     int status;
     float ret;
@@ -188,12 +188,12 @@ double Utility::getReal(char *instr, double minx, double maxx, double def)
         }
         if (ret > maxx)
         {
-            fprintf(stdout, "ERROR: Max. value=%.1f\n\n", maxx);
+            fprintf(stderr, "ERROR: Max. value=%.1f\n\n", maxx);
             continue;
         }
         if (ret < minx)
         {
-            fprintf(stdout, "ERROR: Min. value=%.1f\n\n", minx);
+            fprintf(stderr, "ERROR: Min. value=%.1f\n\n", minx);
             continue;
         }
         break;
@@ -209,7 +209,7 @@ double Utility::getReal(char *instr, double minx, double maxx, double def)
  * @param def 
  * @return 
  */
-int Utility::getInt(char *instr, int minx, int maxx, int def)
+int Utility::getInt(const char *instr, int minx, int maxx, int def)
 {
     int ret, status;
     char line[MAXLINE];
@@ -226,12 +226,12 @@ int Utility::getInt(char *instr, int minx, int maxx, int def)
         }
         if (ret > maxx)
         {
-            fprintf(stdout, "ERROR: Max. value=%d\n\n", maxx);
+            fprintf(stderr, "ERROR: Max. value=%d\n\n", maxx);
             continue;
         }
         if (ret < minx)
         {
-            fprintf(stdout, "ERROR: Min. value=%d\n\n", minx);
+            fprintf(stderr, "ERROR: Min. value=%d\n\n", minx);
             continue;
         }
         break;
@@ -322,7 +322,7 @@ void Utility::getPath(string str, string *path)
  *
  *
  */
-char Utility::promptForYesNo(char *title, char *prompt)
+char Utility::promptForYesNo(char *title, const char *prompt)
 {
     cout << "\n" << title << "\n";
     string promptMessage = string(prompt) + "(y/n) ? [y]";
@@ -347,7 +347,7 @@ char Utility::promptForYesNo(char *title, char *prompt)
  * @return
  *
  */
-char Utility::promptForYesNo(const char *title, char *prompt)
+char Utility::promptForYesNo(const char *title, const char *prompt)
 {
     cout << "\n" << title << "\n";
     string promptMessage = string(prompt) + "(y/n) ? [y]";
@@ -374,9 +374,9 @@ void Utility::error( char *msg,...)
     va_list ap;
 
     va_start(ap, msg);
-    fprintf(stdout, "\n\nERROR: ");
-    vfprintf(stdout, msg, ap);
-    fprintf(stdout, "\n\n");
+    fprintf(stderr, "\n\nERROR: ");
+    vfprintf(stderr, msg, ap);
+    fprintf(stderr, "\n\n");
     va_end(ap);
 }
 
@@ -389,9 +389,9 @@ void Utility::warning( char *msg,...)
     va_list ap;
 
     va_start(ap, msg);
-    fprintf(stdout, "\n\nWARNING: ");
-    vfprintf(stdout, msg, ap);
-    fprintf(stdout, "\n\n");
+    fprintf(stderr, "\n\nWARNING: ");
+    vfprintf(stderr, msg, ap);
+    fprintf(stderr, "\n\n");
     va_end(ap);
 }
 
@@ -404,9 +404,9 @@ void Utility::error( const char *msg,...)
     va_list ap;
 
     va_start(ap, msg);
-    fprintf(stdout, "\n\nERROR: ");
-    vfprintf(stdout, msg, ap);
-    fprintf(stdout, "\n\n");
+    fprintf(stderr, "\n\nERROR: ");
+    vfprintf(stderr, msg, ap);
+    fprintf(stderr, "\n\n");
     va_end(ap);
 }
 
@@ -419,9 +419,9 @@ void Utility::warning( const char *msg,...)
     va_list ap;
 
     va_start(ap, msg);
-    fprintf(stdout, "\n\nWARNING: ");
-    vfprintf(stdout, msg, ap);
-    fprintf(stdout, "\n\n");
+    fprintf(stderr, "\n\nWARNING: ");
+    vfprintf(stderr, msg, ap);
+    fprintf(stderr, "\n\n");
     va_end(ap);
 }
 
@@ -459,6 +459,17 @@ void Utility::info(const char *msg,...)
 }
 
 
+    
+/**
+ * 
+ */
+void Utility::myname( char *myname)
+{
+    strcpy(myname, "clustalw\0");
+}
+
+
+    
 /**
  * Change:
  * Mark 25-1-2007. I made this change to get around the problem of having to keep track
