@@ -6,7 +6,7 @@
 #ifndef UTILITY_H
 #define UTILITY_H
 
-#include <stdlib.h>
+#include <cstdlib>
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
@@ -22,14 +22,16 @@ class Utility
 {
     public:
         Utility();
+	virtual ~Utility(){};
+
         char* rTrim(char *str);
         void rTrim(string *str);
         char* blankToUnderscore(char *str);
         string blankToUnderscore(string str);
         void getStr(string instr, string& outstr);
         char getChoice(string instr);
-        double getReal(char *instr, double minx, double maxx, double def);
-        int getInt(char *instr,int minx,int maxx, int def);
+        double getReal(const char *instr, double minx, double maxx, double def);
+        int getInt(const char *instr,int minx,int maxx, int def);
         unsigned long getUniqueSequenceIdentifier();
         bool lineType(char *line, const char *code);
 
@@ -37,16 +39,17 @@ class Utility
         
         void getPath(string str, string *path);
         
-        virtual char promptForYesNo(char *title,char *prompt);
-        virtual char promptForYesNo(const char *title,char *prompt);
+        virtual char promptForYesNo(char *title, const char *prompt);
+        virtual char promptForYesNo(const char *title, const char *prompt);
         virtual void error( char *msg,...);
         virtual void error( const char *msg,...);
         virtual void warning( char *msg,...);
         virtual void warning( const char *msg,...);
         virtual void info( char *msg,...);
         virtual void info( const char *msg,...);
-        template <class T> T MIN(T x, T y){if (x <= y){return x;}return y;};
-        template <class T> T MAX(T x, T y){if (x >= y){return x;}return y;};
+        virtual void myname( char *myname );
+        template <class T> T MIN(T x, T y){if (x <= y){return x;}return y;}
+        template <class T> T MAX(T x, T y){if (x >= y){return x;}return y;}
         // Note the following function will never be used from this class. It is for the
         // QT version. I need it here so that I can add the function to QTUtility.
         virtual void setInfoLabelPtr(QLabel* ptrToLabelObj);
