@@ -98,7 +98,8 @@ CommandLineParser::CommandLineParser(StringArray* args, bool xmenus)
     setNumIterations(-1),
     setTreeAlgorithm(-1),
     setMaxSeqLen(-1),
-    setStatsFile(-1)
+    setStatsFile(-1),
+    setOutputPim(-1)
 {
     int ctr=0;
     
@@ -128,7 +129,7 @@ CommandLineParser::CommandLineParser(StringArray* args, bool xmenus)
     catch(const exception &ex)
     {
         cerr << ex.what() << endl;
-        cerr << "Terminating program. Cannot continue\n";
+        cerr << "Terminating program. Cannot continue" << std::endl;
         exit(1);
     }
                            
@@ -304,10 +305,11 @@ CommandLineParser::CommandLineParser(StringArray* args, bool xmenus)
                                            clusterAlgorithm);
     cmdLinePara[ctr++] = getCmdLineDataStruct("maxseqlen", &setMaxSeqLen, INTARG, NULL);
     cmdLinePara[ctr++] = getCmdLineDataStruct("stats", &setStatsFile, FILARG, NULL);
+    cmdLinePara[ctr++] = getCmdLineDataStruct("pim", &setOutputPim, NOARG, NULL);
     cmdLinePara[ctr++] = getCmdLineDataStruct("", NULL, -1, NULL);
     // FIXME: final ctr index is hardcoded in CommandLineParser
     
-    parseParams(args, xmenus); 
+    parseParams(args, xmenus);
 }
 
 CommandLineParser::~CommandLineParser()
@@ -352,9 +354,9 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
 
     if (!xmenus && userParameters->getDisplayInfo())
     {
-        cout << "\n\n\n";
+        cout <<  std::endl << std::endl << std::endl;
         cout << " CLUSTAL " << userParameters->getRevisionLevel() 
-             << " Multiple Sequence Alignments\n\n\n";
+             << " Multiple Sequence Alignments" << std::endl << std::endl << std::endl;
     }
 
     doAlign = doConvert = doAlignUseOldTree = doGuideTreeOnly = doTreeFromAlign = false;
@@ -420,8 +422,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
         {
             if (sscanf((*paramArg)[setMaxSeqLen].c_str(),"%d", &temp) != 1) 
             {
-                cout << "Bad option for /maxseqlen (must be int)\n";
-                temp = 0;
+                reportBadOptionAndExit("maxseqlen", "integer");
             }
         }
         if(temp > 0)
@@ -430,7 +431,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
         }
         else
         {
-            cout << "Cannot use a negative value for maximum sequence length. Using default\n";
+            cerr << "Cannot use a negative value for maximum sequence length. Using default"  << std::endl;
         }
         
     }
@@ -444,7 +445,13 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
         }
     }
 
-    
+
+    if (setOutputPim != -1)
+    {
+            userParameters->setOutputPim(true);
+    }
+
+
     /*if(setDoIteration != -1)
     {
         userParameters->setDoRemoveFirstIteration(true);
@@ -475,7 +482,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
             }
             else
             {
-                cout << "Unknown option for iteration. Setting to NONE\n";
+                cerr << "Unknown option for iteration. Setting to NONE"  << std::endl;
                 userParameters->setDoRemoveFirstIteration(NONE);
             }
         }
@@ -489,7 +496,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
             }
         #endif
                 
-        cout << "clustalw option list:-\n";
+        cout << "clustalw option list:-" << std::endl;
         
         for (i = 0; cmdLineVerb[i].str[0] != '\0'; i++) 
         {
@@ -501,13 +508,13 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
                 if (cmdLineVerb[i].arg !=  NULL)
                 {     
                     cout << "=" << cmdLineVerb[i].arg->at(0);
-                    for(j = 1; j < cmdLineVerb[i].arg->size() - 1; j++)
+                    for(j = 1; j < (int)cmdLineVerb[i].arg->size() - 1; j++)
                     {
                         cout << " OR " << cmdLineVerb[i].arg->at(j);
                     }
                 }
             }
-            cout << "\n";
+            cout << std::endl;
         }
         for (i = 0; cmdLineFile[i].str[0] != '\0'; i++) 
         {
@@ -520,13 +527,13 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
                 {
                     
                     cout << "=" << cmdLineFile[i].arg->at(0);
-                    for(j = 1; j < cmdLineFile[i].arg->size() - 1; j++)
+                    for(j = 1; j < (int)cmdLineFile[i].arg->size() - 1; j++)
                     {
                         cout << " OR " << cmdLineFile[i].arg->at(j);
                     }
                 }
             }
-            cout << "\n";
+            cout << std::endl;
         }
         for (i = 0; cmdLinePara[i].str[0] != '\0'; i++) 
         {
@@ -539,13 +546,13 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
                 {
                     
                     cout << "=" << cmdLinePara[i].arg->at(0);
-                    for(j = 1; j < cmdLinePara[i].arg->size() - 1; j++)
+                    for(j = 1; j < (int)cmdLinePara[i].arg->size() - 1; j++)
                     {
                         cout << " OR " << cmdLinePara[i].arg->at(j);
                     }
                 }
             }
-            cout << "\n";
+            cout << std::endl;
         }
         exit(1);
     }
@@ -567,19 +574,19 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
                 userParameters->setDNAFlag(false);
                 userParameters->setExplicitDNAFlag(true);
                 msg = "Sequence type explicitly set to Protein";
-                cout << msg << "\n";
+                cout << msg << std::endl;
             }
             else if(temp == 1) 
             {
                 msg = "Sequence type explicitly set to DNA";
-                cout << msg << "\n";
+                cout << msg << std::endl;
                 userParameters->setDNAFlag(true);
                 userParameters->setExplicitDNAFlag(true);
             }
             else
             {
                 msg = "Unknown sequence type " + (*paramArg)[setType];
-                cout << "\n" << msg << endl;
+                cerr << std::endl << msg << endl;
             }
             #if DEBUGFULL 
                 if(logObject && DEBUGLOG)
@@ -611,8 +618,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if((*paramArg)[setInfile].length() <= 0) 
         {
-            cout << "Bad sequence file name\n";
-            exit(1);
+            exitWithErrorMsg("Bad sequence file name");
         }
         userParameters->setSeqName((*paramArg)[setInfile]);
 
@@ -657,8 +663,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if((*paramArg)[setProfile1].length() <= 0) 
         {
-            cout << "\nBad profile 1 file name\n";
-            exit(1);
+            exitWithErrorMsg("Bad profile 1 file name");
         }
                 
         clustalObj->profile1Input((*paramArg)[setProfile1]);
@@ -668,13 +673,11 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if((*paramArg)[setProfile2].length() <= 0) 
         {
-            cout << "\nBad profile 2 file name\n";
-            exit(1);
+            exitWithErrorMsg("Bad profile 2 file name");
         }
         if(userParameters->getProfile1Empty()) 
         {
-            cout << "\nOnly 1 profile file (profile 2) specified.\n";
-            exit(1);
+            exitWithErrorMsg("Only 1 profile file (profile 2) specified.");
         }
         
         clustalObj->profile2Input((*paramArg)[setProfile2]);
@@ -694,7 +697,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         userParameters->setInteractive(true);
         if (setQuiet!=-1) {
-            cout << "interactive menu: overriding -quiet\n";
+            cout << "interactive menu: overriding " << default_commandsep << "quiet" << std::endl;
             userParameters->setDisplayInfo(true);
             utilityObject->beQuiet(false);
         }
@@ -716,8 +719,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if(userParameters->getEmpty()) 
         {
-            cout << "\nCannot draw tree.  No input alignment file\n";
-            exit(1);
+            exitWithErrorMsg("Cannot draw tree.  No input alignment file");
         }
         else
         { 
@@ -729,8 +731,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if(userParameters->getEmpty()) 
         {
-            cout << "\nCannot bootstrap tree. No input alignment file\n";
-            exit(1);
+            exitWithErrorMsg("Cannot bootstrap tree. No input alignment file");
         }
         else 
         {
@@ -740,8 +741,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
             {
                 if (sscanf((*paramArg)[setBootstrap].c_str(), "%d", &temp) != 1) 
                 {
-                    cout << "Bad option for /bootstrap (must be integer)\n";
-                    temp = 0;
+                    reportBadOptionAndExit("bootstrap", "integer");
                 }
             }
             if(temp > 0)
@@ -756,8 +756,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if(userParameters->getEmpty()) 
         {
-            cout << "\nCannot align sequences.  No input file\n";
-            exit(1);
+            exitWithErrorMsg("Cannot align sequences.  No input file");
         }
         else
         { 
@@ -769,8 +768,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if(userParameters->getEmpty()) 
         {
-            cout << "\nCannot convert sequences.  No input file\n";
-            exit(1);
+            exitWithErrorMsg("Cannot convert sequences.  No input file");
         }
         else
         { 
@@ -782,15 +780,13 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if(userParameters->getEmpty()) 
         {
-            cout << "\nCannot align sequences.  No input file\n";
-            exit(1);
+            exitWithErrorMsg("Cannot align sequences.  No input file");
         }
         else  
         {
            if((*paramArg)[setUseTree].length() == 0) 
            {
-                cout << "\nCannot align sequences.  No tree file specified\n";
-                exit(1);
+               exitWithErrorMsg("Cannot align sequences.  No tree file specified");
            }
            else 
            {
@@ -805,15 +801,13 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if(userParameters->getEmpty()) 
         {
-            cout << "\nCannot align sequences.  No input file\n";
-            exit(1);
+            exitWithErrorMsg("Cannot align sequences.  No input file");
         }
         else  
         {
             if((*paramArg)[setNewTree].length() == 0) 
             {
-                cout << "\nCannot align sequences.  No tree file specified\n";
-                exit(1);
+                exitWithErrorMsg("Cannot align sequences.  No tree file specified");
             }
             else 
             {
@@ -828,20 +822,17 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if(userParameters->getProfile1Empty()) 
         {
-            cout << "\nCannot align profiles.  No input file\n";
-            exit(1);
+            exitWithErrorMsg("Cannot align profiles.  No input file");
         }
         else if(profileType == SEQUENCE) 
         {
-            cout << "\nInvalid option /usetree1.\n";
-            exit(1);
+            reportInvalidOptionAndExit("usetree1");
         }
         else  
         {
             if((*paramArg)[setUseTree1].length() == 0) 
             {
-                cout << "\nCannot align profiles.  No tree file specified\n";
-                exit(1);
+                exitWithErrorMsg("Cannot align profiles.  No tree file specified");
             }
             else 
             {
@@ -856,20 +847,17 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if(userParameters->getProfile1Empty()) 
         {
-            cout << "\nCannot align profiles.  No input file\n";
-            exit(1);
+            exitWithErrorMsg("Cannot align profiles.  No input file");
         }
         else if(profileType == SEQUENCE) 
         {
-            cout << "\nInvalid option /newtree1.\n";
-            exit(1);
+            reportInvalidOptionAndExit("newtree1");
         }
         else  
         {
            if((*paramArg)[setNewTree1].length() == 0) 
            {
-                cout << "\nCannot align profiles.  No tree file specified\n";
-                exit(1);
+               exitWithErrorMsg("Cannot align profiles. No tree file specified");
            }
            else 
            {
@@ -883,20 +871,17 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if(userParameters->getProfile2Empty()) 
         {
-            cout << "\nCannot align profiles.  No input file\n";
-            exit(1);
+            exitWithErrorMsg("Cannot align profiles.  No input file");
         }
         else if(profileType == SEQUENCE) 
         {
-            cout << "\nInvalid option /usetree2.\n";
-            exit(1);
+            reportInvalidOptionAndExit("usetree2");
         }
         else  
         {
             if((*paramArg)[setUseTree2].length() == 0) 
             {
-                cout << "\nCannot align profiles.  No tree file specified\n";
-                exit(1);
+                exitWithErrorMsg("Cannot align profiles.  No tree file specified");
             }
             else 
             {
@@ -911,20 +896,17 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
     {
         if(userParameters->getProfile2Empty()) 
         {
-            cout << "\nCannot align profiles.  No input file\n";
-            exit(1);
+            exitWithErrorMsg("Cannot align profiles.  No input file");
         }
         else if(profileType == SEQUENCE) 
         {
-            cout << "\nInvalid option /newtree2.\n";
-            exit(1);
+            reportInvalidOptionAndExit("newtree2");
         }
         else  
         {
             if((*paramArg)[setNewTree2].length() == 0) 
             {
-                cout << "\nCannot align profiles.  No tree file specified\n";
-                exit(1);
+                exitWithErrorMsg("Cannot align profiles.  No tree file specified");
             }
             else 
             {
@@ -969,8 +951,7 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
 
     if(!doSomething) 
     {
-        cout << "\nNo input file(s) specified\n";
-        exit(1);
+        exitWithErrorMsg("No input file(s) specified");
     }
 
 
@@ -1084,14 +1065,12 @@ void CommandLineParser::parseParams(StringArray* args, bool xmenus)
             clustalObj->bootstrapTree(&phylipTreeName, &clustalTreeName, &nexusTreeName);
     }
 
-    cout << "\n";
+    cout << std::endl;
     
 }
 
-/*
- * The function checkParam is used to put all the parameters and their values in the
- * vectors, and also to check that all parameters that require a value have it.
- */
+
+
 int CommandLineParser::checkParam(StringArray* args, StringArray* params,
                                   StringArray* paramArg)
 {
@@ -1126,11 +1105,11 @@ int CommandLineParser::checkParam(StringArray* args, StringArray* params,
         params->push_back((*args)[0].substr(1));
     }
     
-    for (i = 1; i < args->size(); i++) 
+    for (i = 1; i < (int)args->size(); i++) 
     {
         params->push_back(""); // Empty string!
 
-        for(j = 0; j < (*args)[i].length() - 1; j++)
+        for(j = 0; j < (int)(*args)[i].length() - 1; j++)
         {
             if(isprint((*args)[i][j + 1])) // Character printable?
             {
@@ -1147,9 +1126,9 @@ int CommandLineParser::checkParam(StringArray* args, StringArray* params,
     // extract paramArgs in next step
 
     
-    if (args->size() > MAXARGS)
+    if ((int)args->size() > MAXARGS)
     {
-        cout << "Error: too many command line arguments\n";
+        cerr << "Error: too many command line arguments\n";
         return(-1);
     }
     /*
@@ -1204,8 +1183,8 @@ int CommandLineParser::checkParam(StringArray* args, StringArray* params,
 
     if(paramArg->size() != params->size())
     {
-        cout << "There is something wrong with arguments. Lengths different\n";
-        exit(1);
+        cerr << "There is something wrong with arguments. Lengths different\n";
+        return -1;
     }
     
     /*
@@ -1234,8 +1213,8 @@ int CommandLineParser::checkParam(StringArray* args, StringArray* params,
                 
                 if ((cmdLinePara[match[i]].type != NOARG) && ((*paramArg)[i] == "")) 
                 {
-                    cout <<  "Error: parameter required for /" << (*params)[i] << endl;
-                    exit(1);
+                    cerr <<  "Error: parameter required for " << default_commandsep << (*params)[i] << endl;
+                    return -1;
                 
                 /* Andreas Wilm (UCD) 2008-03-19:
                  *  conversion nowadays unnecessary and breaks things
@@ -1288,8 +1267,8 @@ int CommandLineParser::checkParam(StringArray* args, StringArray* params,
                 if ((cmdLineFile[match[i]].type != NOARG) &&
                                     ((*paramArg)[i] == "")) 
                 {
-                    cout << "Error: parameter required for /" << (*params)[i] << endl;
-                    exit(1);
+                    cerr << "Error: parameter required for " << default_commandsep << (*params)[i] << endl;
+                    return -1;
                 }
                 break;
             }
@@ -1324,8 +1303,8 @@ int CommandLineParser::checkParam(StringArray* args, StringArray* params,
                 *cmdLineVerb[match[i]].flag = i;
                 if ((cmdLineVerb[match[i]].type != NOARG) && ((*paramArg)[i] == "")) 
                 {
-                    cout << "Error: parameter required for /" << (*params)[i] << endl;
-                    exit(1);
+                    cerr << "Error: parameter required for " << default_commandsep << (*params)[i] << endl;
+                    return -1;
                 }
                 break;
             }
@@ -1340,8 +1319,8 @@ int CommandLineParser::checkParam(StringArray* args, StringArray* params,
     {
         if (match[i] == -1) 
         {
-            cout << "Error: unknown option " << default_commandsep << (*params)[i] << endl;
-            exit(1);
+            cerr << "Error: unknown option " << default_commandsep << (*params)[i] << endl;
+            return -1;
         }
     }
     return(num);
@@ -1381,7 +1360,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setNumIterations].c_str(),"%d", &temp) != 1) 
             {
-                cout << "Bad option for /numiter (must be int)\n";
+                reportBadOptionAndExit("numiter", "int");
                 temp = 0;
             }
         }
@@ -1391,7 +1370,7 @@ void CommandLineParser::setOptionalParam()
         }
         else
         {
-            cout << "Cannot use a negative value for number of iterations. Using default\n";
+            exitWithErrorMsg("Cannot use a negative value for number of iterations.");
         }
     }
 
@@ -1424,7 +1403,7 @@ void CommandLineParser::setOptionalParam()
             }
             else
             {
-                cout << "\nUnknown SCORE type: " << (*paramArg)[setScore] << endl;
+                cerr << "\nUnknown SCORE type: " << (*paramArg)[setScore] << endl;
                 #if DEBUGFULL 
                     if(logObject && DEBUGLOG)
                     {
@@ -1449,8 +1428,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setSeed].c_str(),"%d",&temp) != 1) 
             {
-                cout << "Bad option for /seed (must be integer)\n";
-                temp = 0;
+                reportBadOptionAndExit("seed", "integer");
             }
         }
         if(temp > 0)
@@ -1482,7 +1460,7 @@ void CommandLineParser::setOptionalParam()
             }
             else
             {
-                cout << "Unknown option for clustering algorithm. Using default\n";
+                cerr << "Unknown option for clustering algorithm. Using default\n";
                 userParameters->setClusterAlgorithm(NJ);
             }
         }
@@ -1535,7 +1513,7 @@ void CommandLineParser::setOptionalParam()
                 default:
                     // FIXME AW: 1.83 behaves the same, but shouldnt
                     // we exit here?
-                    cout << "\nUnknown OUTPUT type: " << (*paramArg)[setOutput] << endl;
+                    exitWithErrorMsg("Unknown OUTPUT type: " + (*paramArg)[setOutput]);
             }
         }
     }
@@ -1566,7 +1544,7 @@ void CommandLineParser::setOptionalParam()
                     userParameters->setOutputTreeNexus(true);
                     break;
                 default:
-                    cout << "\nUnknown OUTPUT TREE type: " 
+                    cerr << "\nUnknown OUTPUT TREE type: " 
                          << (*paramArg)[setOutputTree] << endl;
             }
         }
@@ -1611,7 +1589,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setKtuple].c_str(),"%d",&_ktup)!=1) 
             {
-                cout << "Bad option for /ktuple (must be integer)\n";
+                reportBadOptionAndExit("ktuple", "integer");
                 _ktup = 0;
             }
         }
@@ -1626,6 +1604,9 @@ void CommandLineParser::setOptionalParam()
                     userParameters->setDNAKtup(_ktup);
                     userParameters->setWindowGap(_ktup + 4);
                     userParameters->setDNAWindowGap(_ktup + 4);
+                } else {
+                    // see comment in bug 185
+                    cerr << "WARNING: Ignoring invalid ktuple of " << _ktup <<  " (must be <=4)" << std::endl;
                 }
             }
             else 
@@ -1636,6 +1617,11 @@ void CommandLineParser::setOptionalParam()
                     userParameters->setAAKtup(_ktup);
                     userParameters->setWindowGap(_ktup + 3);
                     userParameters->setAAWindowGap(_ktup + 3);
+                    // AW: why set setDNAWindowGap? we are in AA mode
+                    // userParameters->setDNAWindowGap(_ktup + 4);
+                } else {
+                    // see comment in bug 185
+                   cerr << "WARNING: Ignoring invalid ktuple of " << _ktup << " (must be <=2)" << std::endl;
                 }
             }
         }
@@ -1655,14 +1641,14 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setPairGap].c_str(),"%d",&_windgap)!=1) 
             {
-                cout << "Bad option for /pairgap (must be integer)\n";
+                reportBadOptionAndExit("pairgap", "integer");
                 _windgap = 0;
             }
             if(_windgap > 0)
             {
                 if(userParameters->getDNAFlag()) 
                 {
-                    if(temp > userParameters->getKtup()) 
+                    if(_windgap > userParameters->getKtup()) 
                     {
                         userParameters->setWindowGap(_windgap);
                         userParameters->setDNAWindowGap(_windgap);
@@ -1694,8 +1680,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setTopDiags].c_str(),"%d",&_signif)!=1) 
             {
-                cout << "Bad option for /topdiags (must be integer)\n";
-                _signif = 0;
+                reportBadOptionAndExit("topdiags", "integer");
             }
         }
         if(_signif > 0)
@@ -1734,7 +1719,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setWindow].c_str(),"%d",&_window)!=1) 
             {
-                cout << "Bad option for /window (must be integer)\n";
+                reportBadOptionAndExit("window", "integer");
                 _window = 0;
             }
         }
@@ -1995,7 +1980,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setMaxDiv].c_str(),"%d",&temp)!=1) 
             {
-                cout << "Bad option for /maxdiv (must be integer)\n";
+                reportBadOptionAndExit("maxdiv", "integer");
                 temp = 0;
             }
         }
@@ -2019,8 +2004,7 @@ void CommandLineParser::setOptionalParam()
         if((*paramArg)[setGapDist].length() > 0)
             if (sscanf((*paramArg)[setGapDist].c_str(),"%d",&temp)!=1) 
             {
-                cout << "Bad option for /gapdist (must be integer)\n";
-                temp = 0;
+                reportBadOptionAndExit("gapdist", "integer");
             }
         if (temp >= 0)
         {
@@ -2035,8 +2019,7 @@ void CommandLineParser::setOptionalParam()
         if((*paramArg)[setDebug].length() > 0)
             if (sscanf((*paramArg)[setDebug].c_str(),"%d",&temp)!=1) 
             {
-                cout << "Bad option for /debug (must be integer)\n";
-                temp = 0;
+                reportBadOptionAndExit("debug", "integer");
             }
         if (temp >= 0)
         {
@@ -2081,7 +2064,7 @@ void CommandLineParser::setOptionalParam()
             }
             else
             {
-                cout << "\nUnknown case " <<  (*paramArg)[setCase] << endl;
+                cerr << "\nUnknown case " <<  (*paramArg)[setCase] << endl;
             }
         }
     }
@@ -2108,7 +2091,7 @@ void CommandLineParser::setOptionalParam()
             }
             else
             {
-                cout << "\nUnknown SEQNO option " << (*paramArg)[setSeqNo] << endl;
+                cerr << "\nUnknown SEQNO option " << (*paramArg)[setSeqNo] << endl;
             }
         }
     }
@@ -2139,7 +2122,7 @@ void CommandLineParser::setOptionalParam()
             }
             else
             {
-                cout << "\nUnknown Sequence range  option " 
+                cerr << "\nUnknown Sequence range  option " 
                      << (*paramArg)[setSeqNoRange] << endl;
             }
         }
@@ -2166,7 +2149,7 @@ void CommandLineParser::setOptionalParam()
             if (sscanf((*paramArg)[setRange].c_str(), "%d%[ :,-]%d", &iFirstRes,
                         &ignore, &iLastRes) != 3) 
             {
-                cout << "setRange:  Syntax Error: Cannot set range, should be from:to \n";
+                cerr << "setRange:  Syntax Error: Cannot set range, should be from:to \n";
             }
             else
             {
@@ -2190,7 +2173,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setGapOpen].c_str(),"%f",&ftemp) != 1) 
             {
-                cout << "Bad option for /gapopen (must be real number)\n";
+                reportBadOptionAndExit("gapopen", "real number");
                 ftemp = 0.0;
             }
             if(ftemp >= 0.0)
@@ -2224,7 +2207,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setGapExtend].c_str(),"%f",&ftemp) != 1) 
             {
-               cout << "Bad option for /gapext (must be real number)\n";
+                reportBadOptionAndExit("gapext", "real number");
                ftemp = 0.0;
             }
             if(ftemp >= 0)
@@ -2258,8 +2241,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setTransWeight].c_str(), "%f", &ftemp) != 1) 
             {
-                cout << "Bad option for /transweight (must be real number)\n";
-                ftemp = 0.0;
+                reportBadOptionAndExit("transweight", "real number");
             }
         }
         userParameters->setTransitionWeight(ftemp);
@@ -2280,8 +2262,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setPWGapOpen].c_str(), "%f", &ftemp) != 1) 
             {
-                cout << "Bad option for /pwgapopen (must be real number)\n";
-                ftemp = 0.0;
+                reportBadOptionAndExit("pwgapopen", "real number");
             }
         }
         if(ftemp >= 0.0)
@@ -2315,8 +2296,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setPWGapExtend].c_str(), "%f", &ftemp) != 1) 
             {
-               cout << "Bad option for /pwgapext (must be real number)\n";
-               ftemp = 0.0;
+                reportBadOptionAndExit("pwgapext", "real number");
             }
         }
         if(ftemp >= 0)
@@ -2361,7 +2341,7 @@ void CommandLineParser::setOptionalParam()
         }
         else
         {
-            cout << "\nUnknown OUTPUT ORDER type " <<  (*paramArg)[setOutOrder] << endl;
+            cerr << "\nUnknown OUTPUT ORDER type " <<  (*paramArg)[setOutOrder] << endl;
         }
     }
 
@@ -2391,7 +2371,7 @@ void CommandLineParser::setOptionalParam()
         }
         else
         {
-            cout << "\nUnknown bootlabels type " << (*paramArg)[setBootLabels] << endl;
+            cerr << "\nUnknown bootlabels type " << (*paramArg)[setBootLabels] << endl;
         }
     }
 
@@ -2507,7 +2487,7 @@ void CommandLineParser::setOptionalParam()
             }
             else
             {
-                cout << "\nUnknown case " << (*paramArg)[setSecStructOutput] << endl;
+                cerr << "\nUnknown case " << (*paramArg)[setSecStructOutput] << endl;
             }
         }
     }
@@ -2528,8 +2508,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setHelixGap].c_str(), "%d", &temp) != 1) 
             {
-                cout << "Bad option for /helixgap (must be integer)\n";
-                temp = 0;
+                reportBadOptionAndExit("helixgap", "integer");
             }
         }
         if (temp >= 1 && temp <= 9)
@@ -2553,8 +2532,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setStrandGap].c_str(), "%d", &temp) != 1) 
             {
-                cout << "Bad option for /strandgap (must be integer)\n";
-                temp = 0;
+                reportBadOptionAndExit("strandgap", "integer");
             }
         }
         if (temp >= 1 && temp <= 9)
@@ -2578,8 +2556,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setLoopGap].c_str(), "%d", &temp) != 1) 
             {
-                cout << "Bad option for /loopgap (must be integer)\n";
-                temp = 0;
+                reportBadOptionAndExit("loopgap", "integer");
             }
         }
         if (temp >= 1 && temp <= 9)
@@ -2602,7 +2579,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setTerminalGap].c_str(), "%d", &temp) != 1) 
             {
-                cout << "Bad option for /terminalgap (must be integer)\n";
+                reportBadOptionAndExit("terminalgap", "integer");
                 temp = 0;
             }
         }
@@ -2628,7 +2605,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setHelixEndIn].c_str(), "%d", &temp) != 1) 
             {
-                cout << "Bad option for /helixendin (must be integer)\n";
+                reportBadOptionAndExit("helixendin", "integer");
                 temp = 0;
             }
         }
@@ -2653,7 +2630,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setHelixEndOut].c_str(), "%d", &temp) != 1) 
             {
-                cout << "Bad option for /helixendout (must be integer)\n";
+                reportBadOptionAndExit("helixendout", "integer");
                 temp = 0;
             }
         }
@@ -2678,8 +2655,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setStrandEndIn].c_str(), "%d", &temp) != 1) 
             {
-                cout << "Bad option for /strandendin (must be integer)\n";
-                temp = 0;
+                reportBadOptionAndExit("strandendin", "integer");
             }
         }
         if (temp >= 0 && temp <= 3)
@@ -2703,8 +2679,7 @@ void CommandLineParser::setOptionalParam()
         {
             if (sscanf((*paramArg)[setStrandEndOut].c_str(), "%d", &temp) != 1) 
             {
-                cout << "Bad option for /strandendout (must be integer)\n";
-                temp = 0;
+                reportBadOptionAndExit("strandendout", "integer");
             }
         }
         if (temp >= 0 && temp <= 3)
@@ -2770,7 +2745,7 @@ void CommandLineParser::printCmdLineData(const CmdLineData& temp)
     else
     {
         cout << "The number of elements is " << temp.arg->size() << std::endl;
-        for(int i = 0; i < temp.arg->size(); i++)
+        for(int i = 0; i < (int)temp.arg->size(); i++)
         {
             cout << "The " << i << "th element is: " << temp.arg->at(i) << endl;
         }
@@ -2790,5 +2765,32 @@ string CommandLineParser::ConvertStringToLower(string strToConvert)
    return strToConvert;
 }
 
+
+
+
+void  CommandLineParser::exitWithErrorMsg(string msg)
+{
+    cerr << "ERROR: " << msg << std::endl;
+    exit(1);
+}
+
+void CommandLineParser::reportBadOptionAndExit(string option, string expectedType)
+{
+    string msg;
+    msg = "Bad option for ";
+    msg += default_commandsep;// has to be added separately
+    msg += option + ": expected " +  expectedType;
+    exitWithErrorMsg(msg);
+}
+
+void CommandLineParser::reportInvalidOptionAndExit(string option)
+{
+    string msg = "Invalid option ";
+    msg += default_commandsep;// has to be added separately
+    msg += option;
+    exitWithErrorMsg(msg);
+}
+
+
 }
 
