@@ -263,7 +263,7 @@ int ClusterTree::dnaDistanceMatrix(ofstream* treeFile, clustalw::Alignment *alig
             {
                 if (e == 0)
                 {
-                    cout << "\n WARNING: sequences " << m << " and " << n 
+                    cerr << "\n WARNING: sequences " << m << " and " << n 
                          << " are non-overlapping\n";
                     k = 0.0;
                     p = 0.0;
@@ -304,7 +304,7 @@ int ClusterTree::dnaDistanceMatrix(ofstream* treeFile, clustalw::Alignment *alig
             {
                 if (e == 0)
                 {
-                    cout << "\n WARNING: sequences " << m << " and " << n 
+                    cerr << "\n WARNING: sequences " << m << " and " << n 
                          << " are non-overlapping\n";;
                     p = 0.0;
                     q = 0.0;
@@ -562,7 +562,6 @@ bool ClusterTree::isAmbiguity(int c)
 void ClusterTree::calcPercIdentity(ofstream* pfile, clustalw::Alignment *alignPtr)
 {
     clustalw::DistMatrix percentMat;
-    char residue;
   
     float ident;
     int nmatch;
@@ -974,17 +973,17 @@ void ClusterTree::promptForBoolSeedAndNumTrials()
 void ClusterTree::printErrorMessageForBootstrap(int totalOverspill, int totalDists, 
                                                 int nfails)
 {
-    cout << "\n";
-    cout << "\n WARNING: " << totalOverspill 
+    cerr << "\n";
+    cerr << "\n WARNING: " << totalOverspill 
          << " of the distances out of a total of " 
          << totalDists << " times" << clustalw::userParameters->getBootNumTrials();
-    cout << "\n were out of range for the distance correction.";
-    cout << "\n This affected " << nfails << " out of " 
+    cerr << "\n were out of range for the distance correction.";
+    cerr << "\n This affected " << nfails << " out of " 
          << clustalw::userParameters->getBootNumTrials() << " bootstrap trials.";
-    cout << "\n This may not be fatal but you have been warned!" << "\n";
-    cout << "\n SUGGESTIONS: 1) turn off the correction";
-    cout << "\n           or 2) remove the most distant sequences";
-    cout << "\n           or 3) use the PHYLIP package.\n\n";
+    cerr << "\n This may not be fatal but you have been warned!" << "\n";
+    cerr << "\n SUGGESTIONS: 1) turn off the correction";
+    cerr << "\n           or 2) remove the most distant sequences";
+    cerr << "\n           or 3) use the PHYLIP package.\n\n";
             
     if (clustalw::userParameters->getMenuFlag())
     {
